# pykeepass-stubs

Type stubs for [pykeepass].

This is a stub-only distribution that improves type-checking for projects using `pykeepass`.

- Target package: `pykeepass`
- Distribution name: `pykeepass-stubs`
- Status: partial stubs ([PEP 561])

## Versioning policy

- `pykeepass-stubs` uses its own version stream (not lockstep with `pykeepass`).
- Compatibility is declared via package requirements.
- Current supported runtime range: `pykeepass>=4.1.1.post1,<4.2`.

[PEP 561]: https://peps.python.org/pep-0561/ "PEP 561 – Distributing and Packaging Type Information"
[pykeepass]: https://github.com/libkeepass/pykeepass "GitHub Repository"
